==> webkit2gtk_2.18.6.orig.tar.xz: webkitgtk-2.18.6/Source/WebCore/dom/RejectedPromiseTracker.h <==
/*
 * Copyright (C) 2017 Apple Inc. All rights reserved.
 * Copyright (C) 2017 Yusuke Suzuki <utatane.tea@gmail.com>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include <runtime/JSPromise.h>
#include <runtime/WeakGCMap.h>
#include <wtf/Forward.h>
#include <wtf/Noncopyable.h>
#include <wtf/Vector.h>

namespace JSC {
class VM;
}

namespace WebCore {

class DOMPromise;
class JSDOMGlobalObject;
class ScriptExecutionContext;
class UnhandledPromise;

class RejectedPromiseTracker {
    WTF_MAKE_NONCOPYABLE(RejectedPromiseTracker);
public:
    explicit RejectedPromiseTracker(ScriptExecutionContext&, JSC::VM&);
    ~RejectedPromiseTracker();

    void promiseRejected(JSC::ExecState&, JSDOMGlobalObject&, JSC::JSPromise&);
    void promiseHandled(JSC::ExecState&, JSDOMGlobalObject&, JSC::JSPromise&);

    void processQueueSoon();

private:
    void reportUnhandledRejections(Vector<UnhandledPromise>&&);
    void reportRejectionHandled(Ref<DOMPromise>&&);

    ScriptExecutionContext& m_context;
    Vector<UnhandledPromise> m_aboutToBeNotifiedRejectedPromises;
    JSC::WeakGCMap<JSC::JSPromise*, JSC::JSPromise> m_outstandingRejectedPromises;
};

} // namespace WebCore

==> webkit2gtk_2.20.1.orig.tar.xz: webkitgtk-2.20.1/Source/WebCore/dom/RejectedPromiseTracker.h <==
/*
 * Copyright (C) 2017 Apple Inc. All rights reserved.
 * Copyright (C) 2017 Yusuke Suzuki <utatane.tea@gmail.com>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include <JavaScriptCore/JSPromise.h>
#include <JavaScriptCore/WeakGCMap.h>
#include <wtf/Forward.h>
#include <wtf/Noncopyable.h>
#include <wtf/Vector.h>

namespace JSC {
class VM;
}

namespace WebCore {

class DOMPromise;
class JSDOMGlobalObject;
class ScriptExecutionContext;
class UnhandledPromise;

class RejectedPromiseTracker {
    WTF_MAKE_NONCOPYABLE(RejectedPromiseTracker);
public:
    explicit RejectedPromiseTracker(ScriptExecutionContext&, JSC::VM&);
    ~RejectedPromiseTracker();

    void promiseRejected(JSC::ExecState&, JSDOMGlobalObject&, JSC::JSPromise&);
    void promiseHandled(JSC::ExecState&, JSDOMGlobalObject&, JSC::JSPromise&);

    void processQueueSoon();

private:
    void reportUnhandledRejections(Vector<UnhandledPromise>&&);
    void reportRejectionHandled(Ref<DOMPromise>&&);

    ScriptExecutionContext& m_context;
    Vector<UnhandledPromise> m_aboutToBeNotifiedRejectedPromises;
    JSC::WeakGCMap<JSC::JSPromise*, JSC::JSPromise> m_outstandingRejectedPromises;
};

} // namespace WebCore
